This locations example was created to help users setup their own location data. The locations Scandia and Belleville are close in space, to illustrate that only a minimum number of images will be downloaded to get the soil information (proximal locations may fall in the same raster).
exkansasThis data.frame has 3 rows and the following 3 columns:
Unique identifier of a given location.
Latitude coordinate, in decimal degrees.
Longitude coordinate, in decimal degrees.